# Condensed: Intro to Use Machine Learning or Deep Learning algorithms

Summary: You can use any machine learning or deep learning algorithms to complete the tasks. Make sure you have them installed in bash script.

# Intro to Use Machine Learning or Deep Learning algorithms

You can use any machine learning or deep learning algorithms to complete the tasks. Make sure you have them installed in bash script.
